@@ -3,7 +3,7 @@ package Complete::Bash;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-01-28'; # DATE
 our $DIST = 'Complete-Bash'; # DIST
-our $VERSION = '0.333'; # VERSION
+our $VERSION = '0.334'; # VERSION
 
 use 5.010001;
 use strict;
@@ -563,15 +563,29 @@ sub format_completion {
     }
 
   WORKAROUND_PREVENT_BASH_FROM_INSERTING_SPACE:
-    if (defined($path_sep) && @$words == 1) {
-        my $re = qr/\Q$path_sep\E\z/;
-        my $word;
-        if (ref($words->[0]) eq 'HASH') {
-            $words = [$words->[0], {word=>"$words->[0] "}] if
-                $words->[0]{word} =~ $re;
-        } else {
-            $words = [$words->[0], "$words->[0] "]
-                if $words->[0] =~ $re;
+    {
+        last unless @$words == 1;
+        if (defined $path_sep) {
+            my $re = qr/\Q$path_sep\E\z/;
+            my $word;
+            if (ref $words->[0] eq 'HASH') {
+                $words = [$words->[0], {word=>"$words->[0]{word} "}] if
+                    $words->[0]{word} =~ $re;
+            } else {
+                $words = [$words->[0], "$words->[0] "]
+                    if $words->[0] =~ $re;
+            }
+            last;
+        }
+
+        if ($hcomp->{is_partial} ||
+                ref $words->[0] eq 'HASH' && $words->[0]{is_partial}) {
+            if (ref $words->[0] eq 'HASH') {
+                $words = [$words->[0], {word=>"$words->[0]{word} "}];
+            } else {
+                $words = [$words->[0], "$words->[0] "];
+            }
+            last;
         }
     }
 
@@ -743,7 +757,7 @@ Complete::Bash - Completion routines for bash shell
 
 =head1 VERSION
 
-This document describes version 0.333 of Complete::Bash (from Perl distribution Complete-Bash), released on 2020-01-28.
+This document describes version 0.334 of Complete::Bash (from Perl distribution Complete-Bash), released on 2020-01-28.
 
 =head1 DESCRIPTION
 
